;; Generated package description from svg-lib.el  -*- no-byte-compile: t -*-
(define-package "svg-lib" "0.3.0.20240102.102609" "SVG tags, progress bars & icons" '((emacs "27.1")) :commit "f62279a4edbe2f67faf573d09b211653acea9668" :maintainer '("Nicolas P. Rougier" . "Nicolas.Rougier@inria.fr") :keywords '("svg" "icons" "tags" "convenience") :url "https://github.com/rougier/svg-lib")
